SystemOrganization addCategory: #ConfigurationOfSignals!

Object subclass: #ConfigurationOfSignals
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSignals'!

!ConfigurationOfSignals class methodsFor: 'private' stamp: 'mt 10/6/2010 16:13:19.712'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSignals class methodsFor: 'private' stamp: 'mt 10/6/2010 16:13:19.77'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfSignals class methodsFor: 'metacello tool support' stamp: 'mt 10/6/2010 16:13:19.858'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSignals class methodsFor: 'metacello tool support' stamp: 'mt 10/6/2010 16:13:19.913'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSignals class methodsFor: 'loading' stamp: 'mt 10/6/2010 16:13:20.062'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfSignals class methodsFor: 'metacello tool support' stamp: 'mt 10/6/2010 16:13:20.008'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSignals class methodsFor: 'accessing' stamp: 'mt 10/6/2010 16:13:20.128'!
project

	^self new project! !

!ConfigurationOfSignals class methodsFor: 'unloading Metacello' stamp: 'mt 10/6/2010 16:13:20.188'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSignals methodsFor: 'baselines' stamp: 'mt 10/28/2010 19:55:29.295'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.
		
		spec project: 'OmniBrowser' with: [
			spec
				className: 'ConfigurationOfOmniBrowser';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
		
		spec project: 'AXAnnouncements' with: [
			spec
				className: 'ConfigurationOfAXAnnouncements';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].

		spec
			package: 'Signals';
			package: 'MethodWrappers';
			package: 'SI-Wrapper' with: [spec requires: #('MethodWrappers' 'Signals')];
			package: 'SI-Reflection' with: [spec requires: #('Signals')];
			package: 'SI-OB-Morphic' with: [spec requires: #('OmniBrowser' 'Signals')];
			package: 'SI-Benchmarks' with: [spec requires: #('AXAnnouncements' 'SI-Wrapper' 'Signals')].
		spec
			group: 'default' with: #('Signals');
			group: 'full' with: #('Signals' 'SI-Wrapper' 'SI-Reflection' 'SI-OB-Morphic' 'SI-Benchmarks') ].! !

!ConfigurationOfSignals methodsFor: 'baselines' stamp: 'mt 11/30/2010 17:14:45.304'!
baselineHead: spec 
	<version: 'head-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.
		
		spec project: 'OmniBrowser' with: [
			spec
				className: 'ConfigurationOfOmniBrowser';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
		
		spec project: 'AXAnnouncements' with: [
			spec
				className: 'ConfigurationOfAXAnnouncements';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].

		spec
			package: 'Signals';
			package: 'MethodWrappers';
			package: 'SI-Wrapper' with: [spec requires: #('MethodWrappers' 'Signals')];
			package: 'SI-Reflection' with: [spec requires: #('Signals')];
			package: 'SI-OB-Morphic' with: [spec requires: #('OmniBrowser' 'Signals')];
			package: 'SI-Benchmarks' with: [spec requires: #('AXAnnouncements' 'SI-Wrapper' 'Signals')].
		spec
			group: 'default' with: #('Signals');
			group: 'full' with: #('Signals' 'SI-Wrapper' 'SI-Reflection' 'SI-OB-Morphic' 'SI-Benchmarks') ].! !

!ConfigurationOfSignals methodsFor: 'accessing' stamp: 'mt 10/6/2010 16:13:19.475'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSignals methodsFor: 'versions' stamp: 'mt 10/6/2010 16:51:17.649'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		
		spec
			package: 'Signals' with: 'Signals-mt.26';
			package: 'SI-Wrapper' with: 'SI-Wrapper-mt.1';
			package: 'SI-Reflection' with: 'SI-Reflection-mt.1';
			package: 'SI-OB-Morphic' with: 'SI-OB-Morphic-mt.1';
			package: 'SI-Benchmarks' with: 'SI-Benchmarks-mt.1'].! !

!ConfigurationOfSignals methodsFor: 'versions' stamp: 'mt 10/28/2010 19:46:40.602'!
version101: spec

	<version: '1.0.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		
		spec
			package: 'Signals' with: 'Signals-mt.27';
			package: 'SI-Wrapper' with: 'SI-Wrapper-mt.1';
			package: 'SI-Reflection' with: 'SI-Reflection-mt.1';
			package: 'SI-OB-Morphic' with: 'SI-OB-Morphic-mt.1';
			package: 'SI-Benchmarks' with: 'SI-Benchmarks-mt.1'].! !

!ConfigurationOfSignals methodsFor: 'versions' stamp: 'mt 11/30/2010 17:15:43.299'!
versionHead: spec

	<version: 'head' imports: #('head-baseline')>
	
	spec for: #common do: [spec blessing: #development].! !
